defaultBooleanTrue top-level constant
String
const defaultBooleanTrue
The identifier for the default value to boolean true.
Implementation
const String defaultBooleanTrue = 'true';
The identifier for the default value to boolean true.
const String defaultBooleanTrue = 'true';