copyWith abstract method
Returns a shallow copy of this AccessDeniedException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
AccessDeniedException copyWith({String? message});
Returns a shallow copy of this AccessDeniedException with some or all fields replaced by the given arguments.
@_is.useResult
AccessDeniedException copyWith({String? message});