copyWith abstract method
Returns a shallow copy of this BulkData with some or all fields replaced by the given arguments.
Implementation
@_iss.useResult
BulkData copyWith({
_isd.TableDefinition? tableDefinition,
String? data,
});
Returns a shallow copy of this BulkData with some or all fields replaced by the given arguments.
@_iss.useResult
BulkData copyWith({
_isd.TableDefinition? tableDefinition,
String? data,
});