CloudStorageDirectDownloadEntry class abstract

Grants temporary download access to a database-backed stored file.

Implemented types

Constructors

CloudStorageDirectDownloadEntry({int? id, required String storageId, required String path, required DateTime expiration, required String authKey, String? downloadFileName, String? contentType})
factory
CloudStorageDirectDownloadEntry.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authKey String
Opaque access key carried by the temporary URL.
getter/setter pair
contentType String?
Optional response MIME type override.
getter/setter pair
downloadFileName String?
Optional filename presented to the downloader.
getter/setter pair
expiration DateTime
The expiration time of the temporary URL.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
path String
The path of the file.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageId String
The storage containing the file.
getter/setter pair
table Table<int?>
The table that this row belongs to.
no setteroverride

Methods

copyWith({int? id, String? storageId, String? path, DateTime? expiration, String? authKey, String? downloadFileName, String? contentType}) CloudStorageDirectDownloadEntry
Returns a shallow copy of this CloudStorageDirectDownloadEntry with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

t CloudStorageDirectDownloadEntryTable
final