CloudStorageDirectDownloadEntryIncludeList class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
include ↔ IncludeObject?
The nested includes
getter/setter pairinherited
includes → Map<String, Include?>
Map containing the relation field name as key and the Include object for the foreign table as value.
no setteroverride
limit ↔ int?
The maximum number of rows to return.
getter/setter pairinherited
offset ↔ int?
The number of rows to skip.
getter/setter pairinherited
orderBy ↔ Column?
The column to order by.
getter/setter pairinherited
orderByList ↔ List<Column>?
The columns to order by.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
Accessor for the Table this include is for.
no setteroverride
where ↔ Expression?
Where expression to filter the included list.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited