count method
Future<int>
count(
- DatabaseSession session, {
- WhereExpressionBuilder<
CloudStorageDirectDownloadEntryTable> ? where, - int? limit,
- Transaction? transaction,
Counts the number of rows matching the where expression. If omitted,
will return the count of all rows in the table.
Implementation
Future<int> count(
_is.DatabaseSession session, {
_is.WhereExpressionBuilder<CloudStorageDirectDownloadEntryTable>? where,
int? limit,
_is.Transaction? transaction,
}) async {
return session.db.count<CloudStorageDirectDownloadEntry>(
where: where?.call(CloudStorageDirectDownloadEntry.t),
limit: limit,
transaction: transaction,
);
}