CloudStorageDirectUploadEntry class abstract

Connects a table for handling uploading of files.

Implemented types

Constructors

CloudStorageDirectUploadEntry({int? id, required String storageId, required String path, required DateTime expiration, required String authKey, int? maxFileSize, int? contentLength, bool? preventOverwrite, String? contentType, String? cacheControl, String? contentDisposition, String? contentEncoding, String? customMetadata})
factory
CloudStorageDirectUploadEntry.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authKey ↔ String
Access key for retrieving a private file.
getter/setter pair
cacheControl ↔ String?
HTTP cache control value to store with the uploaded file.
getter/setter pair
contentDisposition ↔ String?
HTTP content disposition value to store with the uploaded file.
getter/setter pair
contentEncoding ↔ String?
HTTP content encoding value to store with the uploaded file.
getter/setter pair
contentLength ↔ int?
Exact expected upload size in bytes, if known.
getter/setter pair
contentType ↔ String?
MIME type to store with the uploaded file.
getter/setter pair
customMetadata ↔ String?
JSON-encoded custom metadata to store with the uploaded file.
getter/setter pair
expiration ↔ DateTime
The expiration time of when the file can be uploaded.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
maxFileSize ↔ int
Maximum accepted upload size in bytes.
getter/setter pair
path ↔ String
The path where the file is stored.
getter/setter pair
preventOverwrite ↔ bool
Whether an existing file must not be overwritten.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageId ↔ String
The storageId, typically public or private.
getter/setter pair
table → Table<int?>
The table that this row belongs to.
no setteroverride

Methods

copyWith({int? id, String? storageId, String? path, DateTime? expiration, String? authKey, int? maxFileSize, int? contentLength, bool? preventOverwrite, String? contentType, String? cacheControl, String? contentDisposition, String? contentEncoding, String? customMetadata}) → CloudStorageDirectUploadEntry
Returns a shallow copy of this CloudStorageDirectUploadEntry with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → CloudStorageDirectUploadEntryTable
final