upsertRow method

Upserts a single CloudStorageDirectUploadEntry and returns the resulting row.

If the row conflicts on the given conflictColumns, the existing row is updated. Otherwise, a new row is inserted.

If updateColumns is provided, only those columns will be updated on conflict. If null, all non-conflict, non-id columns are updated.

If updateWhere is provided, the update only applies when the existing row matches the expression. Returns null if no row was affected — for example when updateWhere does not match the conflicting row.

The returned CloudStorageDirectUploadEntry will have its id field set.

Implementation

Future<CloudStorageDirectUploadEntry?> upsertRow(
  _i1.DatabaseSession session,
  CloudStorageDirectUploadEntry row, {
  required _i1.ColumnSelections<CloudStorageDirectUploadEntryTable>
  conflictColumns,
  _i1.ColumnSelections<CloudStorageDirectUploadEntryTable>? updateColumns,
  _i1.WhereExpressionBuilder<CloudStorageDirectUploadEntryTable>? updateWhere,
  _i1.Transaction? transaction,
}) async {
  return session.db.upsertRow<CloudStorageDirectUploadEntry>(
    row,
    conflictColumns: conflictColumns(CloudStorageDirectUploadEntry.t),
    updateColumns: updateColumns?.call(CloudStorageDirectUploadEntry.t),
    updateWhere: updateWhere?.call(CloudStorageDirectUploadEntry.t),
    transaction: transaction,
  );
}