contentDisposition property
HTTP content disposition value to store with the uploaded file.
Implementation
late final _is.ColumnString contentDisposition;
HTTP content disposition value to store with the uploaded file.
late final _is.ColumnString contentDisposition;