contentEncoding property
HTTP content encoding value to store with the uploaded file.
Implementation
late final _is.ColumnString contentEncoding;
HTTP content encoding value to store with the uploaded file.
late final _is.ColumnString contentEncoding;