customMetadata property
JSON-encoded custom metadata to store with the uploaded file.
Implementation
late final _is.ColumnString customMetadata;
JSON-encoded custom metadata to store with the uploaded file.
late final _is.ColumnString customMetadata;