CloudStorageEntry class abstract

An entry in the database for an uploaded file.

Implemented types

Constructors

CloudStorageEntry({int? id, required String storageId, required String path, required DateTime addedTime, DateTime? expiration, required ByteData byteData, required bool verified, String? contentType, String? cacheControl, String? contentDisposition, String? contentEncoding, String? customMetadata})
factory
CloudStorageEntry.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

addedTime ↔ DateTime
The time when the file was added.
getter/setter pair
byteData ↔ ByteData
The actual data of the uploaded file.
getter/setter pair
cacheControl ↔ String?
HTTP cache control value stored with the file.
getter/setter pair
contentDisposition ↔ String?
HTTP content disposition value stored with the file.
getter/setter pair
contentEncoding ↔ String?
HTTP content encoding value stored with the file.
getter/setter pair
contentType ↔ String?
MIME type stored with the file.
getter/setter pair
customMetadata ↔ String?
JSON-encoded custom metadata stored with the file.
getter/setter pair
expiration ↔ DateTime?
The time at which the file expires and can be deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
path ↔ String
The path where the file is stored.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageId ↔ String
The storageId, typically public or private.
getter/setter pair
table → Table<int?>
The table that this row belongs to.
no setteroverride
verified ↔ bool
True if the file has been verified as uploaded.
getter/setter pair

Methods

copyWith({int? id, String? storageId, String? path, DateTime? addedTime, DateTime? expiration, ByteData? byteData, bool? verified, String? contentType, String? cacheControl, String? contentDisposition, String? contentEncoding, String? customMetadata}) → CloudStorageEntry
Returns a shallow copy of this CloudStorageEntry with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → CloudStorageEntryTable
final

Constants

db → const CloudStorageEntryRepository