upsertRow method

Upserts a single CloudStorageEntry and returns the resulting row.

If the row conflicts on the given conflictColumns, the existing row is updated. Otherwise, a new row is inserted.

If updateColumns is provided, only those columns will be updated on conflict. If null, all non-conflict, non-id columns are updated.

If updateWhere is provided, the update only applies when the existing row matches the expression. Returns null if no row was affected — for example when updateWhere does not match the conflicting row.

The returned CloudStorageEntry will have its id field set.

Implementation

Future<CloudStorageEntry?> upsertRow(
  _is.DatabaseSession session,
  CloudStorageEntry row, {
  required _is.ColumnSelections<CloudStorageEntryTable> conflictColumns,
  _is.ColumnSelections<CloudStorageEntryTable>? updateColumns,
  _is.WhereExpressionBuilder<CloudStorageEntryTable>? updateWhere,
  _is.Transaction? transaction,
}) async {
  return session.db.upsertRow<CloudStorageEntry>(
    row,
    conflictColumns: conflictColumns(CloudStorageEntry.t),
    updateColumns: updateColumns?.call(CloudStorageEntry.t),
    updateWhere: updateWhere?.call(CloudStorageEntry.t),
    transaction: transaction,
  );
}