CloudStorageEntryUpdateTable class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ CloudStorageEntryTable
-
The table instance that this update table operates on.
finalinherited
Methods
-
addedTime(DateTime value)
→ ColumnValue<DateTime, DateTime>
-
-
byteData(ByteData value)
→ ColumnValue<ByteData, ByteData>
-
-
cacheControl(String? value)
→ ColumnValue<String, String>
-
-
contentDisposition(String? value)
→ ColumnValue<String, String>
-
-
contentEncoding(String? value)
→ ColumnValue<String, String>
-
-
contentType(String? value)
→ ColumnValue<String, String>
-
-
customMetadata(String? value)
→ ColumnValue<String, String>
-
-
expiration(DateTime? value)
→ ColumnValue<DateTime, DateTime>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
path(String value)
→ ColumnValue<String, String>
-
-
storageId(String value)
→ ColumnValue<String, String>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
verified(bool value)
→ ColumnValue<bool, bool>
-