copyWith abstract method
Returns a shallow copy of this ClusterInfo with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
ClusterInfo copyWith({List<_i0iseagh.ClusterServerInfo>? servers});
Returns a shallow copy of this ClusterInfo with some or all fields replaced by the given arguments.
@_is.useResult
ClusterInfo copyWith({List<_i0iseagh.ClusterServerInfo>? servers});