copyWith abstract method
Returns a shallow copy of this ClusterServerInfo with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
ClusterServerInfo copyWith({String? serverId});
Returns a shallow copy of this ClusterServerInfo with some or all fields replaced by the given arguments.
@_is.useResult
ClusterServerInfo copyWith({String? serverId});