DatabasePoolManager class abstract interface

Abstract interface for database pool managers. Provides a unified interface for both any database dialect implementation.

Properties

dialect → DatabaseDialect
The dialect of the database pool manager.
no setter
encoder → ValueEncoder
The encoder used to encode objects for storing in the database.
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastDatabaseOperationTime ↔ DateTime?
The last time a database operation was performed. This can be used to determine if the database is sleeping.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializationManager → DatabaseSerializationManager
Access to the serialization manager.
no setter
started → Future<void>
Ensures the database pool is started.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Starts the database pool.
stop() → Future<void>
Closes the database pool.
testConnection() → Future<bool>
Tests the database connection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited