start abstract method

void start()

Starts the database pool.

This method kicks off an async initialization process that must be awaited from started to avoid unhandled futures. Use it only to start the database pool after stop has been called. Otherwise prefer awaiting started instead, since it will lazily initialize the database pool on the first access.

Implementation

void start();