copyWith abstract method

  1. @useResult
Filter copyWith({
  1. String? name,
  2. String? table,
  3. List<FilterConstraint>? constraints,
})

Returns a shallow copy of this Filter with some or all fields replaced by the given arguments.

Implementation

@_iss.useResult
Filter copyWith({
  String? name,
  String? table,
  List<_isd.FilterConstraint>? constraints,
});