deferrable property
Whether the constraint is deferrable and when it is checked by default. Null means the constraint is not deferrable.
Implementation
_isd.DeferrableConstraint? deferrable;
Whether the constraint is deferrable and when it is checked by default. Null means the constraint is not deferrable.
_isd.DeferrableConstraint? deferrable;