lastHeartbeatTime property
Last heartbeat timestamp for this claim entry. Used to detect stale claims that should be cleaned up.
Implementation
DateTime lastHeartbeatTime;
Last heartbeat timestamp for this claim entry. Used to detect stale claims that should be cleaned up.
DateTime lastHeartbeatTime;