FutureCallClaimEntryInclude class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
includes → Map<String, Include?>
Map containing the relation field name as key and the Include object for the foreign table as value.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
Accessor for the Table this include is for.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited