findFirstRow method
Future<FutureCallClaimEntry?>
findFirstRow(
- DatabaseSession session, {
- WhereExpressionBuilder<
FutureCallClaimEntryTable> ? where, - int? offset,
- OrderByBuilder<
FutureCallClaimEntryTable> ? orderBy, - @Deprecated('Use desc() on the orderBy column instead.') bool orderDescending = false,
- OrderByListBuilder<
FutureCallClaimEntryTable> ? orderByList, - Transaction? transaction,
- LockMode? lockMode,
- LockBehavior? lockBehavior,
Returns the first matching FutureCallClaimEntry matching the given query parameters.
Use where to specify which items to include in the return value.
If none is specified, all items will be returned.
To specify the order use orderBy or orderByList
when sorting by multiple columns.
offset defines how many items to skip, after which the next one will be picked.
var youngestPerson = await Persons.db.findFirstRow(
session,
where: (t) => t.lastName.equals('Jones'),
orderBy: (t) => t.age,
);
Implementation
Future<FutureCallClaimEntry?> findFirstRow(
_i1.DatabaseSession session, {
_i1.WhereExpressionBuilder<FutureCallClaimEntryTable>? where,
int? offset,
_i1.OrderByBuilder<FutureCallClaimEntryTable>? orderBy,
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false,
_i1.OrderByListBuilder<FutureCallClaimEntryTable>? orderByList,
_i1.Transaction? transaction,
_i1.LockMode? lockMode,
_i1.LockBehavior? lockBehavior,
}) async {
return session.db.findFirstRow<FutureCallClaimEntry>(
where: where?.call(FutureCallClaimEntry.t),
orderBy: orderBy?.call(FutureCallClaimEntry.t),
orderByList: orderByList?.call(FutureCallClaimEntry.t),
orderDescending: // ignore: deprecated_member_use
orderDescending,
offset: offset,
transaction: transaction,
lockMode: lockMode,
lockBehavior: lockBehavior,
);
}