lastHeartbeatTime property
Last heartbeat timestamp for this claim entry. Used to detect stale claims that should be cleaned up.
Implementation
late final _i1.ColumnDateTime lastHeartbeatTime;
Last heartbeat timestamp for this claim entry. Used to detect stale claims that should be cleaned up.
late final _i1.ColumnDateTime lastHeartbeatTime;