FutureCallClaimEntryUpdateTable class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → FutureCallClaimEntryTable
The table instance that this update table operates on.
finalinherited

Methods

futureCallId(int? value) → ColumnValue<int, int>
lastHeartbeatTime(DateTime value) → ColumnValue<DateTime, DateTime>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited