FutureCallEntryRepository class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<FutureCallEntryTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<FutureCallEntry> rows, {Transaction? transaction})
→ Future<List<FutureCallEntry>>
-
Deletes all FutureCallEntrys in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, FutureCallEntry row, {Transaction? transaction})
→ Future<FutureCallEntry>
-
Deletes a single FutureCallEntry.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<FutureCallEntryTable> where, Transaction? transaction})
→ Future<List<FutureCallEntry>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<FutureCallEntryTable>? where, int? limit, int? offset, OrderByBuilder<FutureCallEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<FutureCallEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<FutureCallEntry>>
-
Returns a list of FutureCallEntrys matching the given query parameters.
-
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<FutureCallEntry?>
-
Finds a single FutureCallEntry by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<FutureCallEntryTable>? where, int? offset, OrderByBuilder<FutureCallEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<FutureCallEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<FutureCallEntry?>
-
Returns the first matching FutureCallEntry matching the given query parameters.
-
insert(DatabaseSession session, List<FutureCallEntry> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<FutureCallEntry>>
-
Inserts all FutureCallEntrys in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, FutureCallEntry row, {Transaction? transaction})
→ Future<FutureCallEntry>
-
Inserts a single FutureCallEntry and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<FutureCallEntryTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on FutureCallEntry rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<FutureCallEntry> rows, {ColumnSelections<FutureCallEntryTable>? columns, Transaction? transaction})
→ Future<List<FutureCallEntry>>
-
Updates all FutureCallEntrys in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<FutureCallEntryUpdateTable> columnValues, Transaction? transaction})
→ Future<FutureCallEntry?>
-
Updates a single FutureCallEntry by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, FutureCallEntry row, {ColumnSelections<FutureCallEntryTable>? columns, Transaction? transaction})
→ Future<FutureCallEntry>
-
Updates a single FutureCallEntry. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<FutureCallEntryUpdateTable> columnValues, required WhereExpressionBuilder<FutureCallEntryTable> where, int? limit, int? offset, OrderByBuilder<FutureCallEntryTable>? orderBy, OrderByListBuilder<FutureCallEntryTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<FutureCallEntry>>
-
Updates all FutureCallEntrys matching the
where expression with the specified columnValues.
Returns the list of updated rows.