FutureCallEntryTable class

Inheritance

Constructors

FutureCallEntryTable({TableRelation? tableRelation})

Properties

columns → List<Column>
List of Column used by the table.
no setteroverride
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
identifier ↔ ColumnString
An optional identifier which can be used to cancel the call.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
name ↔ ColumnString
Name of the future call. Used to find the correct method to call.
latefinal
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduling ↔ ColumnSerializable<FutureCallScheduling>
Specifies how recurring calls should be scheduled. This field is null for one-off future calls.
latefinal
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
serializedObject ↔ ColumnString
The serialized object, used as a parameter to the call.
latefinal
serverId ↔ ColumnString
The id of the server where the call was created.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
time ↔ ColumnDateTime
Time to execute the call.
latefinal
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ FutureCallEntryUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited