FutureCallScheduling class sealed
Generic interface that specifies how recurring calls should be scheduled.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → FutureCallScheduling - Returns a shallow copy of this FutureCallScheduling with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
inherited
-
toJsonForProtocol(
) → dynamic -
Returns a JSON structure of the model, optimized for Protocol communication.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited