copyWith abstract method
Returns a shallow copy of this FutureCallScheduling with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
FutureCallScheduling copyWith();
Returns a shallow copy of this FutureCallScheduling with some or all fields replaced by the given arguments.
@_is.useResult
FutureCallScheduling copyWith();