nullsDistinct property
Whether null values should be considered distinct in this unique index. If null, the database default behavior is used.
Implementation
bool? nullsDistinct;
Whether null values should be considered distinct in this unique index. If null, the database default behavior is used.
bool? nullsDistinct;