LogEntryRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<LogEntryTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<LogEntry> rows, {Transaction? transaction}) Future<List<LogEntry>>
Deletes all LogEntrys in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
deleteRow(DatabaseSession session, LogEntry row, {Transaction? transaction}) Future<LogEntry>
Deletes a single LogEntry.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<LogEntryTable> where, Transaction? transaction}) Future<List<LogEntry>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<LogEntryTable>? where, int? limit, int? offset, OrderByBuilder<LogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<LogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<LogEntry>>
Returns a list of LogEntrys matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<LogEntry?>
Finds a single LogEntry by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<LogEntryTable>? where, int? offset, OrderByBuilder<LogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<LogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<LogEntry?>
Returns the first matching LogEntry matching the given query parameters.
insert(DatabaseSession session, List<LogEntry> rows, {Transaction? transaction, bool ignoreConflicts = false}) Future<List<LogEntry>>
Inserts all LogEntrys in the list and returns the inserted rows.
insertRow(DatabaseSession session, LogEntry row, {Transaction? transaction}) Future<LogEntry>
Inserts a single LogEntry and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<LogEntryTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on LogEntry rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<LogEntry> rows, {ColumnSelections<LogEntryTable>? columns, Transaction? transaction}) Future<List<LogEntry>>
Updates all LogEntrys in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<LogEntryUpdateTable> columnValues, Transaction? transaction}) Future<LogEntry?>
Updates a single LogEntry by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, LogEntry row, {ColumnSelections<LogEntryTable>? columns, Transaction? transaction}) Future<LogEntry>
Updates a single LogEntry. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<LogEntryUpdateTable> columnValues, required WhereExpressionBuilder<LogEntryTable> where, int? limit, int? offset, OrderByBuilder<LogEntryTable>? orderBy, OrderByListBuilder<LogEntryTable>? orderByList, bool orderDescending = false, Transaction? transaction}) Future<List<LogEntry>>
Updates all LogEntrys matching the where expression with the specified columnValues. Returns the list of updated rows.

Operators

operator ==(Object other) bool
The equality operator.
inherited