insert method

Future<List<LogEntry>> insert(
  1. DatabaseSession session,
  2. List<LogEntry> rows, {
  3. Transaction? transaction,
  4. bool ignoreConflicts = false,
})

Inserts all LogEntrys in the list and returns the inserted rows.

The returned LogEntrys will have their id fields set.

This is an atomic operation, meaning that if one of the rows fails to insert, none of the rows will be inserted.

If ignoreConflicts is set to true, rows that conflict with existing rows are silently skipped, and only the successfully inserted rows are returned.

Implementation

Future<List<LogEntry>> insert(
  _i1.DatabaseSession session,
  List<LogEntry> rows, {
  _i1.Transaction? transaction,
  bool ignoreConflicts = false,
}) async {
  return session.db.insert<LogEntry>(
    rows,
    transaction: transaction,
    ignoreConflicts: ignoreConflicts,
  );
}