LogEntryTable class

Inheritance

Constructors

LogEntryTable({TableRelation? tableRelation})

Properties

columns → List<Column>
List of Column used by the table.
no setteroverride
error ↔ ColumnString
Optional error associated with this log entry.
latefinal
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
logLevel ↔ ColumnEnum<LogLevel>
The log level of this entry.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
message ↔ ColumnString
The logging message.
latefinal
messageId ↔ ColumnInt
The message id this entry is associated with, if in a streaming session.
latefinal
order ↔ ColumnInt
The order of this log entry, used for sorting.
latefinal
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
reference ↔ ColumnString
Currently unused.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
serverId ↔ ColumnString
The id of the server which created this log entry.
latefinal
sessionLogId ↔ ColumnInt
The id of the session this log entry is associated with.
latefinal
stackTrace ↔ ColumnString
Optional stack trace associated with this log entry.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
time ↔ ColumnDateTime
Timestamp of this log entry.
latefinal
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ LogEntryUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited