messageId property
The message id this entry is associated with, if in a streaming session.
Implementation
late final _is.ColumnInt messageId;
The message id this entry is associated with, if in a streaming session.
late final _is.ColumnInt messageId;