MessageLogEntry class abstract

A log entry for a message sent in a streaming session.

Implemented types

Constructors

MessageLogEntry({int? id, required int sessionLogId, required String serverId, required int messageId, required String endpoint, required String messageName, required double duration, String? error, String? stackTrace, required bool slow, required int order})
factory
MessageLogEntry.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

duration ↔ double
The duration of handling of this message.
getter/setter pair
endpoint ↔ String
The endpoint this message is associated with.
getter/setter pair
error ↔ String?
Error is set if an error or exception was thrown during the handling of this message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
messageId ↔ int
The id of the message this entry is associated with.
getter/setter pair
messageName ↔ String
The class name of the message this entry is associated with.
getter/setter pair
order ↔ int
Used for sorting the message log.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId ↔ String
The id of the server that handled the message.
getter/setter pair
sessionLogId ↔ int
Id of the session this entry is associated with.
getter/setter pair
slow ↔ bool
The handling of this message was slow.
getter/setter pair
stackTrace ↔ String?
The stack trace of an error that was thrown during the handling of this message.
getter/setter pair
table → Table<int?>
The table that this row belongs to.
no setteroverride

Methods

copyWith({int? id, int? sessionLogId, String? serverId, int? messageId, String? endpoint, String? messageName, double? duration, String? error, String? stackTrace, bool? slow, int? order}) → MessageLogEntry
Returns a shallow copy of this MessageLogEntry with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → MessageLogEntryTable
final

Constants

db → const MessageLogEntryRepository