MessageLogEntryRepository class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<MessageLogEntryTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<MessageLogEntry> rows, {Transaction? transaction})
→ Future<List<MessageLogEntry>>
-
Deletes all MessageLogEntrys in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, MessageLogEntry row, {Transaction? transaction})
→ Future<MessageLogEntry>
-
Deletes a single MessageLogEntry.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<MessageLogEntryTable> where, Transaction? transaction})
→ Future<List<MessageLogEntry>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<MessageLogEntryTable>? where, int? limit, int? offset, OrderByBuilder<MessageLogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<MessageLogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<MessageLogEntry>>
-
Returns a list of MessageLogEntrys matching the given query parameters.
-
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<MessageLogEntry?>
-
Finds a single MessageLogEntry by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<MessageLogEntryTable>? where, int? offset, OrderByBuilder<MessageLogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<MessageLogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<MessageLogEntry?>
-
Returns the first matching MessageLogEntry matching the given query parameters.
-
insert(DatabaseSession session, List<MessageLogEntry> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<MessageLogEntry>>
-
Inserts all MessageLogEntrys in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, MessageLogEntry row, {Transaction? transaction})
→ Future<MessageLogEntry>
-
Inserts a single MessageLogEntry and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<MessageLogEntryTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on MessageLogEntry rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<MessageLogEntry> rows, {ColumnSelections<MessageLogEntryTable>? columns, Transaction? transaction})
→ Future<List<MessageLogEntry>>
-
Updates all MessageLogEntrys in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<MessageLogEntryUpdateTable> columnValues, Transaction? transaction})
→ Future<MessageLogEntry?>
-
Updates a single MessageLogEntry by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, MessageLogEntry row, {ColumnSelections<MessageLogEntryTable>? columns, Transaction? transaction})
→ Future<MessageLogEntry>
-
Updates a single MessageLogEntry. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<MessageLogEntryUpdateTable> columnValues, required WhereExpressionBuilder<MessageLogEntryTable> where, int? limit, int? offset, OrderByBuilder<MessageLogEntryTable>? orderBy, OrderByListBuilder<MessageLogEntryTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<MessageLogEntry>>
-
Updates all MessageLogEntrys matching the
where expression with the specified columnValues.
Returns the list of updated rows.