error property
Error is set if an error or exception was thrown during the handling of this message.
Implementation
late final _is.ColumnString error;
Error is set if an error or exception was thrown during the handling of this message.
late final _is.ColumnString error;