stackTrace property
The stack trace of an error that was thrown during the handling of this message.
Implementation
late final _is.ColumnString stackTrace;
The stack trace of an error that was thrown during the handling of this message.
late final _is.ColumnString stackTrace;