MigrationArtifactStoreReader class abstract interface

Loads migration SQL for running migrations.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listVersions() Future<List<String>>
Lists all available migration versions in ascending order.
inherited
loadDefinitionModuleName(String version) Future<String?>
Loads the module name from the definition of the given migration version.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRepairMigration() Future<RepairMigration?>
Reads the currently available repair migration, if any.
readVersionSql(String version) Future<MigrationVersionSql?>
Reads the stored migration SQL for running migrations.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited