MigrationVersionArtifacts class

A semantic representation of a migration version and its persisted artifacts.

Constructors

MigrationVersionArtifacts({required String version, required String definitionSql, required String migrationSql, required DatabaseDefinition definition, required DatabaseDefinition projectDefinition, required DatabaseMigration migration})
Creates a new migration version artifacts.
const

Properties

definition DatabaseDefinition
The full database definition for this version.
final
definitionSql String
The full database definition SQL for this version.
final
hashCode int
The hash code for this object.
no setterinherited
migration DatabaseMigration
The migration definition for this version.
final
migrationSql String
The incremental migration SQL that leads to this version.
final
moduleName String
The module name associated with the migration.
no setter
projectDefinition DatabaseDefinition
The project-only database definition for this version.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
The version name of the migration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited