QueryLogEntryRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<QueryLogEntryTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<QueryLogEntry> rows, {Transaction? transaction}) Future<List<QueryLogEntry>>
Deletes all QueryLogEntrys in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
deleteRow(DatabaseSession session, QueryLogEntry row, {Transaction? transaction}) Future<QueryLogEntry>
Deletes a single QueryLogEntry.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<QueryLogEntryTable> where, Transaction? transaction}) Future<List<QueryLogEntry>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<QueryLogEntryTable>? where, int? limit, int? offset, OrderByBuilder<QueryLogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<QueryLogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<QueryLogEntry>>
Returns a list of QueryLogEntrys matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<QueryLogEntry?>
Finds a single QueryLogEntry by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<QueryLogEntryTable>? where, int? offset, OrderByBuilder<QueryLogEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<QueryLogEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<QueryLogEntry?>
Returns the first matching QueryLogEntry matching the given query parameters.
insert(DatabaseSession session, List<QueryLogEntry> rows, {Transaction? transaction, bool ignoreConflicts = false}) Future<List<QueryLogEntry>>
Inserts all QueryLogEntrys in the list and returns the inserted rows.
insertRow(DatabaseSession session, QueryLogEntry row, {Transaction? transaction}) Future<QueryLogEntry>
Inserts a single QueryLogEntry and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<QueryLogEntryTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on QueryLogEntry rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<QueryLogEntry> rows, {ColumnSelections<QueryLogEntryTable>? columns, Transaction? transaction}) Future<List<QueryLogEntry>>
Updates all QueryLogEntrys in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<QueryLogEntryUpdateTable> columnValues, Transaction? transaction}) Future<QueryLogEntry?>
Updates a single QueryLogEntry by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, QueryLogEntry row, {ColumnSelections<QueryLogEntryTable>? columns, Transaction? transaction}) Future<QueryLogEntry>
Updates a single QueryLogEntry. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<QueryLogEntryUpdateTable> columnValues, required WhereExpressionBuilder<QueryLogEntryTable> where, int? limit, int? offset, OrderByBuilder<QueryLogEntryTable>? orderBy, OrderByListBuilder<QueryLogEntryTable>? orderByList, bool orderDescending = false, Transaction? transaction}) Future<List<QueryLogEntry>>
Updates all QueryLogEntrys matching the where expression with the specified columnValues. Returns the list of updated rows.

Operators

operator ==(Object other) bool
The equality operator.
inherited