delete method
Future<List<QueryLogEntry> >
delete(
- DatabaseSession session,
- List<
QueryLogEntry> rows, { - Transaction? transaction,
Deletes all QueryLogEntrys in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
Implementation
Future<List<QueryLogEntry>> delete(
_i1.DatabaseSession session,
List<QueryLogEntry> rows, {
_i1.Transaction? transaction,
}) async {
return session.db.delete<QueryLogEntry>(
rows,
transaction: transaction,
);
}