ReadWriteTestEntry class abstract

Database mapping for a read/write test that is performed by the default health checks.

Implemented types

Constructors

ReadWriteTestEntry({int? id, required int number})
factory
ReadWriteTestEntry.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
number ↔ int
A random number, to verify that the write/read was performed correctly.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
The table that this row belongs to.
no setteroverride

Methods

copyWith({int? id, int? number}) → ReadWriteTestEntry
Returns a shallow copy of this ReadWriteTestEntry with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → ReadWriteTestEntryTable
final

Constants

db → const ReadWriteTestEntryRepository