ReadWriteTestEntryRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<ReadWriteTestEntryTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<ReadWriteTestEntry> rows, {Transaction? transaction}) Future<List<ReadWriteTestEntry>>
Deletes all ReadWriteTestEntrys in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
deleteRow(DatabaseSession session, ReadWriteTestEntry row, {Transaction? transaction}) Future<ReadWriteTestEntry>
Deletes a single ReadWriteTestEntry.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<ReadWriteTestEntryTable> where, Transaction? transaction}) Future<List<ReadWriteTestEntry>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<ReadWriteTestEntryTable>? where, int? limit, int? offset, OrderByBuilder<ReadWriteTestEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<ReadWriteTestEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<ReadWriteTestEntry>>
Returns a list of ReadWriteTestEntrys matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<ReadWriteTestEntry?>
Finds a single ReadWriteTestEntry by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<ReadWriteTestEntryTable>? where, int? offset, OrderByBuilder<ReadWriteTestEntryTable>? orderBy, bool orderDescending = false, OrderByListBuilder<ReadWriteTestEntryTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<ReadWriteTestEntry?>
Returns the first matching ReadWriteTestEntry matching the given query parameters.
insert(DatabaseSession session, List<ReadWriteTestEntry> rows, {Transaction? transaction, bool ignoreConflicts = false}) Future<List<ReadWriteTestEntry>>
Inserts all ReadWriteTestEntrys in the list and returns the inserted rows.
insertRow(DatabaseSession session, ReadWriteTestEntry row, {Transaction? transaction}) Future<ReadWriteTestEntry>
Inserts a single ReadWriteTestEntry and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<ReadWriteTestEntryTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on ReadWriteTestEntry rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<ReadWriteTestEntry> rows, {ColumnSelections<ReadWriteTestEntryTable>? columns, Transaction? transaction}) Future<List<ReadWriteTestEntry>>
Updates all ReadWriteTestEntrys in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<ReadWriteTestEntryUpdateTable> columnValues, Transaction? transaction}) Future<ReadWriteTestEntry?>
Updates a single ReadWriteTestEntry by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, ReadWriteTestEntry row, {ColumnSelections<ReadWriteTestEntryTable>? columns, Transaction? transaction}) Future<ReadWriteTestEntry>
Updates a single ReadWriteTestEntry. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<ReadWriteTestEntryUpdateTable> columnValues, required WhereExpressionBuilder<ReadWriteTestEntryTable> where, int? limit, int? offset, OrderByBuilder<ReadWriteTestEntryTable>? orderBy, OrderByListBuilder<ReadWriteTestEntryTable>? orderByList, bool orderDescending = false, Transaction? transaction}) Future<List<ReadWriteTestEntry>>
Updates all ReadWriteTestEntrys matching the where expression with the specified columnValues. Returns the list of updated rows.

Operators

operator ==(Object other) bool
The equality operator.
inherited