upsertRow method

Upserts a single ReadWriteTestEntry and returns the resulting row.

If the row conflicts on the given conflictColumns, the existing row is updated. Otherwise, a new row is inserted.

If updateColumns is provided, only those columns will be updated on conflict. If null, all non-conflict, non-id columns are updated.

If updateWhere is provided, the update only applies when the existing row matches the expression. Returns null if no row was affected — for example when updateWhere does not match the conflicting row.

The returned ReadWriteTestEntry will have its id field set.

Implementation

Future<ReadWriteTestEntry?> upsertRow(
  _i1.DatabaseSession session,
  ReadWriteTestEntry row, {
  required _i1.ColumnSelections<ReadWriteTestEntryTable> conflictColumns,
  _i1.ColumnSelections<ReadWriteTestEntryTable>? updateColumns,
  _i1.WhereExpressionBuilder<ReadWriteTestEntryTable>? updateWhere,
  _i1.Transaction? transaction,
}) async {
  return session.db.upsertRow<ReadWriteTestEntry>(
    row,
    conflictColumns: conflictColumns(ReadWriteTestEntry.t),
    updateColumns: updateColumns?.call(ReadWriteTestEntry.t),
    updateWhere: updateWhere?.call(ReadWriteTestEntry.t),
    transaction: transaction,
  );
}