RepairMigration class

A migration used to repair the database back to a specific migration version.

Constructors

RepairMigration({required String version, required String migrationSql})
Creates a new repair migration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
migrationSql String
The SQL to run to repair the database.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
The version of the repair migration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited