RuntimeSettings class abstract

Runtime settings of the server.

Implemented types

Constructors

RuntimeSettings({int? id, required LogSettings logSettings, required List<LogSettingsOverride> logSettingsOverrides, required bool logServiceCalls, required bool logMalformedCalls})
factory
RuntimeSettings.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pairoverride-getter
logMalformedCalls ↔ bool
True if malformed calls should be logged.
getter/setter pair
logServiceCalls ↔ bool
True if service calls to Serverpod Insights should be logged.
getter/setter pair
logSettings ↔ LogSettings
Log settings.
getter/setter pair
logSettingsOverrides ↔ List<LogSettingsOverride>
List of log setting overrides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
The table that this row belongs to.
no setteroverride

Methods

copyWith({int? id, LogSettings? logSettings, List<LogSettingsOverride>? logSettingsOverrides, bool? logServiceCalls, bool? logMalformedCalls}) → RuntimeSettings
Returns a shallow copy of this RuntimeSettings with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → RuntimeSettingsTable
final

Constants

db → const RuntimeSettingsRepository