RuntimeSettingsTable class

Inheritance

Constructors

RuntimeSettingsTable({TableRelation? tableRelation})

Properties

columns → List<Column>
List of Column used by the table.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
logMalformedCalls ↔ ColumnBool
True if malformed calls should be logged.
latefinal
logServiceCalls ↔ ColumnBool
True if service calls to Serverpod Insights should be logged.
latefinal
logSettings ↔ ColumnSerializable
Log settings.
latefinal
logSettingsOverrides ↔ ColumnSerializable
List of log setting overrides.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String
Name of the table as used in the database.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited