RuntimeSettingsUpdateTable class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → RuntimeSettingsTable
The table instance that this update table operates on.
finalinherited

Methods

logMalformedCalls(bool value) → ColumnValue<bool, bool>
logServiceCalls(bool value) → ColumnValue<bool, bool>
logSettings(LogSettings value) → ColumnValue<LogSettings, LogSettings>
logSettingsOverrides(List<LogSettingsOverride> value) → ColumnValue<List<LogSettingsOverride>, List<LogSettingsOverride>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited