upsertRow method

Upserts a single ServerHealthConnectionInfo and returns the resulting row.

If the row conflicts on the given conflictColumns, the existing row is updated. Otherwise, a new row is inserted.

If updateColumns is provided, only those columns will be updated on conflict. If null, all non-conflict, non-id columns are updated.

If updateWhere is provided, the update only applies when the existing row matches the expression. Returns null if no row was affected — for example when updateWhere does not match the conflicting row.

The returned ServerHealthConnectionInfo will have its id field set.

Implementation

Future<ServerHealthConnectionInfo?> upsertRow(
  _i1.DatabaseSession session,
  ServerHealthConnectionInfo row, {
  required _i1.ColumnSelections<ServerHealthConnectionInfoTable>
  conflictColumns,
  _i1.ColumnSelections<ServerHealthConnectionInfoTable>? updateColumns,
  _i1.WhereExpressionBuilder<ServerHealthConnectionInfoTable>? updateWhere,
  _i1.Transaction? transaction,
}) async {
  return session.db.upsertRow<ServerHealthConnectionInfo>(
    row,
    conflictColumns: conflictColumns(ServerHealthConnectionInfo.t),
    updateColumns: updateColumns?.call(ServerHealthConnectionInfo.t),
    updateWhere: updateWhere?.call(ServerHealthConnectionInfo.t),
    transaction: transaction,
  );
}