ServerHealthConnectionInfoUpdateTable class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → ServerHealthConnectionInfoTable
The table instance that this update table operates on.
finalinherited

Methods

active(int value) → ColumnValue<int, int>
closing(int value) → ColumnValue<int, int>
granularity(int value) → ColumnValue<int, int>
idle(int value) → ColumnValue<int, int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serverId(String value) → ColumnValue<String, String>
timestamp(DateTime value) → ColumnValue<DateTime, DateTime>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited