duration property
The running time of this session, in seconds. May be null if the session is still active.
Implementation
double? duration;
The running time of this session, in seconds. May be null if the session is still active.
double? duration;