SessionLogEntryAttachRepository class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
logs(
DatabaseSession session, SessionLogEntry sessionLogEntry, List< LogEntry> logEntry, {Transaction? transaction}) → Future<void> -
Creates a relation between this SessionLogEntry and the given LogEntrys
by setting each LogEntry's foreign key
sessionLogIdto refer to this SessionLogEntry. -
messages(
DatabaseSession session, SessionLogEntry sessionLogEntry, List< MessageLogEntry> messageLogEntry, {Transaction? transaction}) → Future<void> -
Creates a relation between this SessionLogEntry and the given MessageLogEntrys
by setting each MessageLogEntry's foreign key
sessionLogIdto refer to this SessionLogEntry. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queries(
DatabaseSession session, SessionLogEntry sessionLogEntry, List< QueryLogEntry> queryLogEntry, {Transaction? transaction}) → Future<void> -
Creates a relation between this SessionLogEntry and the given QueryLogEntrys
by setting each QueryLogEntry's foreign key
sessionLogIdto refer to this SessionLogEntry. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited