delete method

Future<List<SessionLogEntry>> delete(
  1. DatabaseSession session,
  2. List<SessionLogEntry> rows, {
  3. Transaction? transaction,
})

Deletes all SessionLogEntrys in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.

Implementation

Future<List<SessionLogEntry>> delete(
  _i1.DatabaseSession session,
  List<SessionLogEntry> rows, {
  _i1.Transaction? transaction,
}) async {
  return session.db.delete<SessionLogEntry>(
    rows,
    transaction: transaction,
  );
}