upsertRow method

Upserts a single SessionLogEntry and returns the resulting row.

If the row conflicts on the given conflictColumns, the existing row is updated. Otherwise, a new row is inserted.

If updateColumns is provided, only those columns will be updated on conflict. If null, all non-conflict, non-id columns are updated.

If updateWhere is provided, the update only applies when the existing row matches the expression. Returns null if no row was affected — for example when updateWhere does not match the conflicting row.

The returned SessionLogEntry will have its id field set.

Implementation

Future<SessionLogEntry?> upsertRow(
  _i1.DatabaseSession session,
  SessionLogEntry row, {
  required _i1.ColumnSelections<SessionLogEntryTable> conflictColumns,
  _i1.ColumnSelections<SessionLogEntryTable>? updateColumns,
  _i1.WhereExpressionBuilder<SessionLogEntryTable>? updateWhere,
  _i1.Transaction? transaction,
}) async {
  return session.db.upsertRow<SessionLogEntry>(
    row,
    conflictColumns: conflictColumns(SessionLogEntry.t),
    updateColumns: updateColumns?.call(SessionLogEntry.t),
    updateWhere: updateWhere?.call(SessionLogEntry.t),
    transaction: transaction,
  );
}