duration property
The running time of this session, in seconds. May be null if the session is still active.
Implementation
late final _is.ColumnDouble duration;
The running time of this session, in seconds. May be null if the session is still active.
late final _is.ColumnDouble duration;