SessionLogFilter class abstract

The log filter is used when searching for specific log entries.

Implemented types

Constructors

SessionLogFilter({String? endpoint, String? method, String? futureCall, required bool slow, required bool error, required bool open, int? lastSessionLogId, DateTime? startTime, DateTime? endTime})
factory
SessionLogFilter.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

endpoint ↔ String?
The endpoint to get logs from. Null will return logs from any endpoint.
getter/setter pair
endTime ↔ DateTime?
Inclusive upper bound on session start time. Null means no upper bound.
getter/setter pair
error ↔ bool
If true, only return sessions ending with an exception.
getter/setter pair
futureCall ↔ String?
The name of a future call to get logs from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastSessionLogId ↔ int?
Last session id to start the list of logs from. Used for pagination.
getter/setter pair
method ↔ String?
The method to get logs from. Null will return logs from any method.
getter/setter pair
open ↔ bool
If true, only return open sessions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slow ↔ bool
If true, only return slow sessions.
getter/setter pair
startTime ↔ DateTime?
Inclusive lower bound on session start time. Null means no lower bound.
getter/setter pair

Methods

copyWith({String? endpoint, String? method, String? futureCall, bool? slow, bool? error, bool? open, int? lastSessionLogId, DateTime? startTime, DateTime? endTime}) → SessionLogFilter
Returns a shallow copy of this SessionLogFilter with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited