copyWith abstract method
Returns a shallow copy of this SessionLogResult with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
SessionLogResult copyWith({List<_i783h20h.SessionLogInfo>? sessionLog});
Returns a shallow copy of this SessionLogResult with some or all fields replaced by the given arguments.
@_is.useResult
SessionLogResult copyWith({List<_i783h20h.SessionLogInfo>? sessionLog});