VectorDistanceFunction enum

Vector distance functions exposed by pgvector.

Inheritance
Implemented types
Available extensions

Values

l2 → const VectorDistanceFunction

L2 (Euclidean) distance

innerProduct → const VectorDistanceFunction

Inner product distance

cosine → const VectorDistanceFunction

Cosine distance

l1 → const VectorDistanceFunction

L1 (Manhattan) distance

hamming → const VectorDistanceFunction

Hamming distance (binary vectors)

jaccard → const VectorDistanceFunction

Jaccard distance (binary vectors)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String name) → VectorDistanceFunction

Constants

values → const List<VectorDistanceFunction>
A constant List of the values in this enum, in order of their declaration.