ClientCallOpContext class base

The context of a client call operation. Subclasses represent web, method, and method streaming calls.

Inheritance
Implementers

Constructors

ClientCallOpContext({required String serverName, required String serverId, required String serverRunMode, OperationType? operationType, UuidValue? sessionId, AuthenticationInfo? userAuthInfo, required ConnectionInfo connectionInfo, required Uri uri})
Creates a new ClientCallOpContext.
const

Properties

connectionInfo → ConnectionInfo
The client connection information.
final
hashCode → int
The hash code for this object.
no setterinherited
operationType → OperationType?
The type of operation. Null if unknown, for example if an HTTP request is invalid and no call operation can be determined.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId → String
The id of the Serverpod server that submitted the event.
finalinherited
serverName → String
The name of the individual server that submitted the event. This is the empty string if the event is not associated with a specific server.
finalinherited
serverRunMode → String
The run mode of the Serverpodserver that submitted the event.
finalinherited
sessionId → UuidValue?
The session ID of the operation, if available.
finalinherited
uri → Uri
The URI that the client invoked.
final
userAuthInfo → AuthenticationInfo?
The user authentication information, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this context to a Json map representation, e.g. for logging or tags.
override
toString() → String
Returns a string representation of this context.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited