ClientDatabaseSession class

A DatabaseSession backed by a local SQLite file, for client-side models (database: client / database: all).

Implemented types

Properties

db Database
The database to access.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
logQuery LogQueryFunction?
Optional function to log a query.
no setteroverride
logWarning LogWarningFunction?
Optional function to log a warning during the execution of a query.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction Transaction?
Optional transaction to use for all database queries.
no setteroverride

Methods

close() Future<void>
Closes the underlying SQLite database.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

open(String path, DatabaseSerializationManager serializationManager, {List<MigrationVersionSql> clientMigrations = const [], bool runMigrations = true, bool isDebugMode = false}) Future<ClientDatabaseSession>
Opens a database session at path using serializationManager for schema access. When runMigrations is true (default), pending clientMigrations are applied before the session is returned. If isDebugMode is true, the database integrity will be verified after the migrations are applied to provide feedback of possible issues. On a Flutter application, this should be set to kDebugMode.