Column<T> class abstract

Abstract class representing a database Column. Subclassed by the different supported column types such as ColumnInt or ColumnString.

Available extensions

Constructors

Column(String _columnName, Table table, {bool hasDefault = false, String? fieldName})
Creates a new Column, this is typically done in generated code only.

Properties

columnName → String
Name of the Column.
no setter
fieldName → String
Name of the field in the model
no setter
fieldQueryAlias → String
Field name alias for the Column to be used in queries.
no setter
hasDefault → bool
flag to tell if this Column has any default value
final
hashCode → int
The hash code for this object.
no setterinherited
queryAlias → String
Query alias for the Column.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table
Table that column belongs to.
final
type → Type
Corresponding dart Type.
final

Methods

asc() → Order

Available on Column<T>, provided by the ColumnOrderingOperations extension

Creates an Order with the column ordered ascending.
desc() → Order

Available on Column<T>, provided by the ColumnOrderingOperations extension

Creates an Order with the column ordered descending.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited