ColumnByteData class

A Column holding ByteData.

Inheritance

Constructors

ColumnByteData(String columnName, Table table, {bool hasDefault = false, String? fieldName})
Creates a new Column, this is typically done in generated code only.

Properties

columnName → String
Name of the Column.
no setterinherited
fieldName → String
Name of the field in the model
no setterinherited
fieldQueryAlias → String
Field name alias for the Column to be used in queries.
no setterinherited
hasDefault → bool
flag to tell if this Column has any default value
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
queryAlias → String
Query alias for the Column.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table
Table that column belongs to.
finalinherited
type → Type
Corresponding dart Type.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited