ColumnGeographyPolygon class

A Column holding a GeographyPolygon from PostGIS.

Inheritance

Constructors

ColumnGeographyPolygon(String columnName, Table table, {bool hasDefault = false, String? fieldName})
Creates a new Column, this is typically done in generated code only.

Properties

columnName String
Name of the Column.
no setterinherited
fieldName String
Name of the field in the model
no setterinherited
fieldQueryAlias String
Field name alias for the Column to be used in queries.
no setterinherited
hasDefault bool
flag to tell if this Column has any default value
finalinherited
hashCode int
The hash code for this object.
no setterinherited
queryAlias String
Query alias for the Column.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table Table
Table that column belongs to.
finalinherited
type Type
Corresponding dart Type.
finalinherited

Methods

contains(Geography other) Expression
Returns an Expression that is true when this column's geometry spatially contains other — wraps ST_Covers (geography-compatible equivalent of ST_Contains).
inherited
distance(Geography other) ColumnGeographyDistance
Returns a ColumnGeographyDistance suitable for use in orderBy — wraps ST_Distance.
inherited
distanceWithin(Geography other, double meters) Expression
Returns an Expression that is true when this column's geometry is within meters metres of other — wraps ST_DWithin.
inherited
equals(GeographyPolygon value) Expression
Creates an Expression checking if the value in the column equals the specified value.
inherited
inSet(Set<GeographyPolygon> values) Expression
Creates and Expression checking if the value in the column is included in the specified set of values. If the set is empty the expression will match no rows.
inherited
intersects(Geography other) Expression
Returns an Expression that is true when this column's geometry intersects other — wraps ST_Intersects.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(GeographyPolygon value) Expression
Creates an Expression checking if the value in the column does not equal the specified value.
inherited
notInSet(Set<GeographyPolygon> values) Expression
Creates and Expression checking if the value in the column is NOT included in the specified set of values. If the set is empty the expression will match all rows.
inherited
toString() String
A string representation of this object.
inherited
within(Geography other) Expression
Returns an Expression that is true when this column's geometry is spatially within other — wraps ST_CoveredBy (geography-compatible equivalent of ST_Within).
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited