ConnectionHeaderType class

A class representing the type of connection directives for the Connection header.

Constructors

ConnectionHeaderType.parse(String value)
Parses a value and returns the corresponding ConnectionHeaderType instance. If the value does not match any predefined types, it returns a custom instance.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The string representation of the connection directive.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override