Cron class

Represents a cron schedule.

Constructors

Cron.parse(String cronExpression)
Parses the cronExpression.
factory

Properties

days → List<int>?
The days of this cron schedule.
final
hashCode → int
The hash code for this object.
no setterinherited
hours → List<int>?
The hours of this cron schedule.
final
minutes → List<int>?
The minutes of this cron schedule.
final
months → List<int>?
The months of this cron schedule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → List<int>?
The seconds of this cron schedule.
final
weekdays → List<int>?
The weekdays of this cron schedule.
final

Methods

nextTime() → DateTime
Returns the next run time, in UTC.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited