DatabaseAnalyzer class abstract

Analyzes the structure of Databases.

Available extensions

Constructors

DatabaseAnalyzer({required Database database})
Creates a new DatabaseAnalyzer for the given database.

Properties

database → Database
The Database to analyze.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyze() → Future<DatabaseDefinition>
Analyze the structure of the database.
getColumnDefinitions({required String schemaName, required String tableName}) → Future<List<ColumnDefinition>>
Retrieves the definitions of the columns in the database.
getCurrentDatabaseName() → Future<String>
Retrieves the current database from the database.
getForeignKeyDefinitions({required String schemaName, required String tableName}) → Future<List<ForeignKeyDefinition>>
Retrieves the definitions of the foreign keys in the database.
getIndexDefinitions({required String schemaName, required String tableName}) → Future<List<IndexDefinition>>
Retrieves the definitions of the indexes in the database.
getTableDefinitions() → Future<List<TableDefinition>>
Retrieves the definitions of the tables in the database.
getTargetTableDefinitions() → List<TableDefinition>

Available on DatabaseAnalyzer, provided by the DatabaseAnalyzerExtensions extension

Gets the target database definition for the current dialect.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited