getColumnDefinitions abstract method
Retrieves the definitions of the columns in the database.
Implementation
Future<List<ColumnDefinition>> getColumnDefinitions({
required String schemaName,
required String tableName,
});
Retrieves the definitions of the columns in the database.
Future<List<ColumnDefinition>> getColumnDefinitions({
required String schemaName,
required String tableName,
});