getTableDefinitions abstract method
Retrieves the definitions of the tables in the database.
Implementation
Future<List<TableDefinition>> getTableDefinitions();
Retrieves the definitions of the tables in the database.
Future<List<TableDefinition>> getTableDefinitions();