DatabaseAnalyzerExtensions extension

Extensions on DatabaseAnalyzer to add functionality not overridden by the concrete analyzer implementations.

on

Methods

getTargetTableDefinitions() List<TableDefinition>

Available on DatabaseAnalyzer, provided by the DatabaseAnalyzerExtensions extension

Gets the target database definition for the current dialect.