hint property
String?
get
hint
A hint on how to remedy an error, if provided by the database.
Implementation
String? get hint;
A hint on how to remedy an error, if provided by the database.
String? get hint;