position property
int?
get
position
Returns the position in the query where the error occurred.
Implementation
int? get position;
Returns the position in the query where the error occurred.
int? get position;