DatabaseUtil class abstract
Provides utility functions for working with the Database.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
runInTransactionOrSavepoint<
R> (Database database, Transaction? transaction, TransactionFunction< R> f, {TransactionSettings? settings}) → Future<R> -
Runs the closure
fin isolation and undoes any changes to the database in caseffails.