serverName property

String serverName
final

The name of the individual server that submitted the event. This is the empty string if the event is not associated with a specific server.

Implementation

final String serverName;