EndpointConnector class

The EndpointConnector associates a name with and endpoint and its EndpointMethodConnectors.

Constructors

EndpointConnector({required String name, required Endpoint endpoint, required Map<String, EndpointMethodConnector> methodConnectors})
Creates a new EndpointConnector.

Properties

endpoint → Endpoint
Reference to the Endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
methodConnectors → Map<String, EndpointMethodConnector>
All EndpointMethodConnectors associated with the Endpoint.
final
name → String
Name of the Endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited