EndpointNotFoundException class

The endpoint was not found.

Inheritance

Constructors

EndpointNotFoundException(String message)
Creates a new EndpointNotFoundException.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
Description of the error.
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited