noCacheFiles constant

Set<String> const noCacheFiles

Files that should never be cached to prevent issues with stale app manifests, service workers, or version mismatches.

Implementation

static const noCacheFiles = {
  'index.html',
  'flutter_service_worker.js',
  'flutter_bootstrap.js',
  'manifest.json',
  'version.json',
};