HealthComponentType enum

Known component types for health indicators.

These values follow the RFC Health Check Response Format conventions. Custom component types can also be used as plain strings.

Inheritance
Available extensions

Values

datastore → const HealthComponentType

Data storage components (databases, caches, file systems).

system → const HealthComponentType

System-level components (CPU, memory, process health).

component → const HealthComponentType

Generic component type for custom services.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HealthComponentType>
A constant List of the values in this enum, in order of their declaration.