HnswIndexQueryOptions class

Query options for the HNSW index.

Inheritance

Constructors

HnswIndexQueryOptions({int efSearch = 40, IterativeScan iterativeScan = IterativeScan.off, int maxScanTuples = 20000, int scanMemMultiplier = 1})
Creates a new HNSW index query options object.
const

Properties

efSearch int
The ef search parameter for HNSW index. Default is 40.
final
hashCode int
The hash code for this object.
no setterinherited
iterativeScan IterativeScan
The iterative scan limit. Default is off.
final
maxScanTuples int
The maximum number of tuples to scan. Default is 20000.
final
options Map<String, dynamic>
The options that this runtime parameters group can set. The key is the name of the option as it appears in the SQL statement, and the value is the value to set it to. The value can also be a RuntimeParameters.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMemMultiplier int
The memory multiplier for the scan. Default is 1.
final

Methods

build({required bool isLocal}) String
Returns the SQL statement to set the runtime parameters. If isLocal is true, options are set for the current transaction only and not globally.
inherited
buildCheckValues() String
Returns a SELECT statement to check current values of all options. When running the query, parameters that were not yet set will return null.
inherited
buildStatements({required bool isLocal}) Iterable<String>
Returns a list with the SQL statements to set each runtime parameters. If isLocal is true, options are set for the current transaction only.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited