options property
The options that this runtime parameters group can set. The key is the name of the option as it appears in the SQL statement, and the value is the value to set it to. The value can also be a RuntimeParameters.
Implementation
@override
Map<String, dynamic> get options => <String, dynamic>{
'hnsw.ef_search': efSearch,
'hnsw.iterative_scan': iterativeScan,
'hnsw.max_scan_tuples': maxScanTuples,
'hnsw.scan_mem_multiplier': scanMemMultiplier,
};