IdColumnIterable extension
An extension on iterable for Id columns.
- on
Methods
-
castToIdType(
) → Iterable -
Available on Iterable, provided by the IdColumnIterable extension
Casts the elements of the iterable to the correct id type.
An extension on iterable for Id columns.
Available on Iterable, provided by the IdColumnIterable extension
Casts the elements of the iterable to the correct id type.