orderDescending property
Whether the column should be ordered descending or ascending.
Implementation
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false;
Whether the column should be ordered descending or ascending.
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false;