LockBehavior enum
Specifies the behavior when a lock cannot be immediately acquired.
Values
- wait → const LockBehavior
-
Wait until the lock becomes available.
- noWait → const LockBehavior
-
Throw an exception immediately if the row is locked.
- skipLocked → const LockBehavior
-
Skip rows that are currently locked.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LockBehavior> - A constant List of the values in this enum, in order of their declaration.