LockMode enum

Specifies the type of row-level lock to acquire.

Inheritance
Available extensions

Values

forUpdate → const LockMode

Exclusive lock that blocks all other locks. Use when you intend to update or delete the selected rows.

forNoKeyUpdate → const LockMode

Exclusive lock that allows forKeyShare locks. Use when updating non-key columns only.

forShare → const LockMode

Shared lock that blocks exclusive locks but allows other shared locks. Use when you need to ensure rows don't change while reading.

forKeyShare → const LockMode

Weakest lock that only blocks changes to key columns.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LockMode>
A constant List of the values in this enum, in order of their declaration.