MessageCentralServerpodChannels class abstract

Channels that are listened to by the Serverpod Framework.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

revokedAuthentication(String userIdentifier) String
Used to revoke authentication tokens. The message should be of type RevokedAuthenticationUser, RevokedAuthenticationAuthId or RevokedAuthenticationScope. The userIdentifier should be the AuthenticationInfo.userIdentifier for the concerned user.