endpointName property
The name of the endpoint that is being called.
Implementation
@Deprecated('Use endpoint instead')
String get endpointName => endpoint;
The name of the endpoint that is being called.
@Deprecated('Use endpoint instead')
String get endpointName => endpoint;