returnsVoid property
True if the method returns void. If null, no assumption can be made about the return value.
Implementation
final bool? returnsVoid;
True if the method returns void. If null, no assumption can be made about the return value.
final bool? returnsVoid;