MigrationsApplyResult class abstract

Result of applying database migrations via the Insights endpoint.

Implemented types

Constructors

MigrationsApplyResult({List<String>? migrationsApplied, String? repairMigrationApplied, required bool databaseMatchesTargetState})
factory
MigrationsApplyResult.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

databaseMatchesTargetState bool
Whether the live database schema matches the target schema after applying migrations. false indicates either schema drift between the code's target tables and the live database, or that verification could not run to completion.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
migrationsApplied List<String>?
Versions of regular migrations that were applied. An empty list means applyMigrations was true but the database was already at the latest version. null means applyMigrations was false — no attempt was made to apply regular migrations.
getter/setter pair
repairMigrationApplied String?
Version name of the repair migration that was applied, or null if applyRepairMigration was false, no repair migration file exists, or the repair migration was already applied to this database.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? migrationsApplied, String? repairMigrationApplied, bool? databaseMatchesTargetState}) MigrationsApplyResult
Returns a shallow copy of this MigrationsApplyResult with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited