path property
The string representation of the normalized path, always starting with /.
For example, NormalizedPath('a/b//c/./../d') results in a path of /a/b/d.
Implementation
late final String path = '/${segments.join('/')}';
The string representation of the normalized path, always starting with /.
For example, NormalizedPath('a/b//c/./../d') results in a path of /a/b/d.
late final String path = '/${segments.join('/')}';