OperationEventContext class base

Represents the operation that the event was caused by or in relation to. An operation is a client-originated call / operation or a scheduled operation, i.e. a method call, a streaming call, a web call, or a future call.

Inheritance
Implementers

Constructors

OperationEventContext({required String serverName, required String serverId, required String serverRunMode, OperationType? operationType, UuidValue? sessionId, AuthenticationInfo? userAuthInfo})
Creates a new OperationEventContext.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
operationType → OperationType?
The type of operation. Null if unknown, for example if an HTTP request is invalid and no call operation can be determined.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId → String
The id of the Serverpod server that submitted the event.
finalinherited
serverName → String
The name of the individual server that submitted the event. This is the empty string if the event is not associated with a specific server.
finalinherited
serverRunMode → String
The run mode of the Serverpodserver that submitted the event.
finalinherited
sessionId → UuidValue?
The session ID of the operation, if available.
final
userAuthInfo → AuthenticationInfo?
The user authentication information, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this context to a Json map representation, e.g. for logging or tags.
override
toString() → String
Returns a string representation of this context.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited