PathCacheMaxAge class

DEPRECATED: Use StaticRoute.directory with CacheControlFactory instead A path pattern to match, and the max age that paths that match the pattern should be cached for, in seconds.

Annotations
  • @Deprecated('Use StaticRoute.directory and CacheControlFactory instead')

Constructors

PathCacheMaxAge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited