PostgresValueEncoder class

Overrides the PostgresTextEncoder to add support for ByteData.

Implemented types

Constructors

PostgresValueEncoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(dynamic input, {bool escapeStrings = true, bool hasDefaults = false}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryConvert(Object? input, {bool escapeStrings = false}) String?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited