QueryParametersPositional class

Positional parameters for direct database queries

Implemented types

Constructors

QueryParametersPositional(List<Object?> parameters)
pos params Positional parameters are indicated by using $

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters → List<Object?>
retrieve current parameters
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited