ReadOnlyAccessor<T extends Object, K, R> class abstract

A read-only accessor for extracting typed values from a keyed storage.

This is a flyweight pattern where the accessor defines how to decode a value, and the AccessorState holds the actual data.

Type parameters:

  • T: The decoded type
  • K: The key type used to identify values in storage
  • R: The raw storage type

Constructors

ReadOnlyAccessor(K key, Decoder<T, R> decode)
const

Properties

decode → Decoder<T, R>
Decodes the raw value into the typed value.
final
hashCode int
The hash code for this object.
no setterinherited
key → K
The key used to identify this value in storage.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited