Savepoint class abstract interface

A savepoint in a transaction.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the savepoint.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → Future<void>
Releases the savepoint and any savepoints created after this savepoint.
rollback() → Future<void>
Rolls back the transaction to the state of the savepoint.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited