SecurityContextConfig class

Configuration for the security context.

Constructors

SecurityContextConfig({SecurityContext? apiServer, SecurityContext? webServer, SecurityContext? insightsServer})
Creates a new SecurityContextConfig object.

Properties

apiServer → SecurityContext?
Security context for the API server.
final
hashCode → int
The hash code for this object.
no setterinherited
insightsServer → SecurityContext?
Security context for the insights server.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webServer → SecurityContext?
Security context for the web server.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited