getModuleName method

String getModuleName()

The name of the module that defines the serialization.

This method will be implemented by the generated code.

Implementation

String getModuleName() {
  throw UnimplementedError('This protocol does not have a module name.');
}