connectionsInfo method
Returns information about the current connections to the server.
Implementation
Future<ConnectionsInfo> connectionsInfo() async =>
await _relicServer?.connectionsInfo() ?? (active: 0, closing: 0, idle: 0);
Returns information about the current connections to the server.
Future<ConnectionsInfo> connectionsInfo() async =>
await _relicServer?.connectionsInfo() ?? (active: 0, closing: 0, idle: 0);