httpOptionsResponseHeaders property
HTTP headers used for OPTIONS responses. These headers are sent in addition to the httpResponseHeaders when the request method is OPTIONS.
Implementation
final Headers httpOptionsResponseHeaders;
HTTP headers used for OPTIONS responses. These headers are sent in addition to the httpResponseHeaders when the request method is OPTIONS.
final Headers httpOptionsResponseHeaders;