healthCheckHandler property

HealthCheckHandler? healthCheckHandler
final

HealthCheckHandler for any custom health checks. This can be used to check remotely if all services the server is depending on is up and running.

This parameter serves two purposes:

  1. Registering custom health checks on the legacy health endpoint.
  2. Registering custom health metrics that are stored in the database.

For the first purpose, this parameter is deprecated in favor of the HealthConfig with custom HealthIndicator implementations.

Implementation

final HealthCheckHandler? healthCheckHandler;