httpResponseHeaders property
HTTP headers used by all API responses. Defaults to allowing any cross origin resource sharing (CORS).
Implementation
final Headers httpResponseHeaders;
HTTP headers used by all API responses. Defaults to allowing any cross origin resource sharing (CORS).
final Headers httpResponseHeaders;