SqliteDatabaseLockedException class

Exception thrown when a query cannot acquire a lock on the SQLite database.

This typically happens when transactions run concurrently, or when a query is executed without passing the transaction of an already active transaction.

Inheritance

Constructors

SqliteDatabaseLockedException(String message, {String? code, String? detail, String? hint, String? tableName, String? columnName, String? constraintName, int? position})
Creates a new SqliteDatabaseLockedException.

Properties

code → String?
The error code of the exception.
finalinherited
columnName → String?
The name of the column where the error occurred.
finalinherited
constraintName → String?
The name of the constraint that was violated.
finalinherited
detail → String?
Additional details if provided by the database.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
A hint on how to remedy an error, if provided by the database.
finalinherited
message → String
A message describing the error.
finalinherited
position → int?
The position in the query where the error occurred.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String?
The name of the table where the error occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited