SqliteErrorCode class abstract final

A class containing constants for SQLite error codes.

These error codes are defined in the SQLite documentation at: https://www.sqlite.org/rescode.html

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited