SqliteForeignKeyViolationException class final

Thrown when SQLite PRAGMA foreign_key_check reports one or more rows that violate foreign key constraints.

Implemented types

Constructors

SqliteForeignKeyViolationException(List<Map<String, dynamic>> violations)
Creates a new SqliteForeignKeyViolationException.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Returns the message of the exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
violations List<Map<String, dynamic>>
Rows returned by PRAGMA foreign_key_check.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited