TableRow<T_ID> class abstract interface

Holds data corresponding to a row in the database. Concrete classes are typically generated. Instances of TableRow can also be serialized and either passed to clients or cached.

Implemented types
Implementers
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → T_ID
The id column of the row. Can be null if this row is not yet stored in the database.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<T_ID>
The table that this row belongs to.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
Returns a serialized JSON structure of the model which also includes fields used by the database.
inherited
toJsonForDatabase() → dynamic

Available on TableRow, provided by the TableRowDatabaseJsonExtension extension

Returns the json representation to be sent to the database for storage
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited