id property
T_ID
get
id
The id column of the row. Can be null if this row is not yet stored in the database.
Implementation
T_ID get id;
The id column of the row. Can be null if this row is not yet stored in the database.
T_ID get id;