name property
The name of the template used by this TemplateWidget. Can be a simple name (e.g., 'default') or a path (e.g., 'admin/dashboard')
Implementation
final String name;
The name of the template used by this TemplateWidget. Can be a simple name (e.g., 'default') or a path (e.g., 'admin/dashboard')
final String name;