TransactionSettings class

Settings for a transaction.

Constructors

TransactionSettings({IsolationLevel? isolationLevel, bool deferConstraints = false})
Creates a new transaction settings object.
const

Properties

deferConstraints → bool
Whether foreign key constraints should be deferred until commit.
final
hashCode → int
The hash code for this object.
no setterinherited
isolationLevel → IsolationLevel?
The isolation level of the transaction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited