TwoPartExpression class abstract

A database expression with two parts.

Inheritance

Constructors

TwoPartExpression(Expression expression, Expression _other)
Creates a new TwoPartExpression.

Properties

columns → List<Column>
Returns a list of all Columns in the expression.
no setteroverride
depthFirst → Iterable<Expression>
Iterator for all Expressions in the expression. Iterates elements deterministically depth first.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
operator → String
Returns the expression operator as a string.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subExpressions → List<Expression>
Returns sub expressions for this expression
no setter

Methods

forEachDepthFirstIndexed(void action(int index, Expression expression)) → void
Takes an action for each element.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator &(Expression other) → Expression
Database AND operator.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator |(Expression other) → Expression
Database OR operator.
inherited
operator ~() → Expression
Database NOT operator.
inherited