WebCallOpContext class final

The context of a web call operation.

Inheritance

Constructors

WebCallOpContext({required String serverName, required String serverId, required String serverRunMode, required UuidValue? sessionId, AuthenticationInfo? userAuthInfo, String? remoteInfo, required Uri uri})
Creates a new WebCallOpContext.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
operationType → OperationType?
The type of operation. Null if unknown, for example if an HTTP request is invalid and no call operation can be determined.
finalinherited
remoteInfo → String?
Information identifying the client caller.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId → String
The id of the Serverpod server that submitted the event.
finalinherited
serverName → String
The name of the individual server that submitted the event. This is the empty string if the event is not associated with a specific server.
finalinherited
serverRunMode → String
The run mode of the Serverpodserver that submitted the event.
finalinherited
sessionId → UuidValue?
The session ID of the operation, if available.
finalinherited
uri → Uri
The URI that the client invoked.
finalinherited
userAuthInfo → AuthenticationInfo?
The user authentication information, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this context to a Json map representation, e.g. for logging or tags.
inherited
toString() → String
Returns a string representation of this context.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited