port property
int?
get
port
The port the webserver is listening on, or null if not started.
Implementation
int? get port => _actualPort;
The port the webserver is listening on, or null if not started.
int? get port => _actualPort;