TableRelationBuilder class

Test util for building a table with relations.

Constructors

TableRelationBuilder(Table _table)
Creates a new TableRelationBuilder for the given table.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Table
Builds a table with the relations added.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withRelationsFrom(List<BuilderRelation> relations) → TableRelationBuilder
In iteration order, adds relations from the relation list using the relation aliases.

Operators

operator ==(Object other) → bool
The equality operator.
inherited