CloudStorageDirectDownloadEntryTable class
Constructors
- CloudStorageDirectDownloadEntryTable({TableRelation? tableRelation})
Properties
- authKey ↔ ColumnString
-
Opaque access key carried by the temporary URL.
latefinal
-
columns
→ List<
Column> -
List of
Columnused by the table.no setteroverride - contentType ↔ ColumnString
-
Optional response MIME type override.
latefinal
- downloadFileName ↔ ColumnString
-
Optional filename presented to the downloader.
latefinal
- expiration ↔ ColumnDateTime
-
The expiration time of the temporary URL.
latefinal
- hasColumnMapping → bool
-
Cached flag indicating whether any columns have explicit column names
that differ from their field names. Computed lazily on first access.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
↔ ColumnComparable<
int?> -
The database id.
latefinalinherited
-
managedColumns
→ List<
Column> -
List of Column that are managed by this table.
This is mostly used to exclude columns created by implicit relations.
no setterinherited
- path ↔ ColumnString
-
The path of the file.
latefinal
- queryPrefix → String
-
Query prefix for Columns of the table.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageId ↔ ColumnString
-
The storage containing the file.
latefinal
- tableName → String
-
Name of the table as used in the database.
finalinherited
- tableRelation → TableRelation?
-
Table relation for Columns of the table.
finalinherited
- updateTable ↔ CloudStorageDirectDownloadEntryUpdateTable
-
latefinal
Methods
-
getRelationTable(
String relationField) → Table? -
Returns
TableColumnRelationfor the givenrelationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited