DatabaseBulkData class

Provides a way to export raw data from the database. The data is serialized using JSON. Primarily used for Serverpod Insights.

Constructors

DatabaseBulkData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

approximateRowCount({required Database database, required String table}) Future<int>
Returns the approximate number of rows in the provided table.
executeQueries({required Database database, required List<String> queries}) Future<BulkQueryResult>
Executes a series of queries and returns the last result as a BulkQueryResult.
exportTableData({required Database database, required String table, Object? lastId, int limit = 100, Filter? filter}) Future<BulkData>
Exports data from the provided table.