DatabaseMigrationVersionModel class
Represents a version of a database migration.
- Implemented types
- Implementers
Constructors
- DatabaseMigrationVersionModel({required String module, required String version, DateTime? timestamp})
-
DatabaseMigrationVersionModel.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- module ↔ String
-
The module the migration belongs to.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ DateTime?
-
The timestamp of the migration. Only set if the migration is applied.
getter/setter pair
- version ↔ String
-
The version of the migration.
getter/setter pair
Methods
-
copyWith(
{String? module, String? version, Object? timestamp = _Undefined}) → DatabaseMigrationVersionModel - Returns a shallow copy of this DatabaseMigrationVersionModel with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited