started property
Future<void>
get
started
Ensures the database pool is started.
If start has been previously called, this will simply return the future kicked off by start. Otherwise, it will create an initialization process and return the future. This method alone is enough to ensure the database pool is first started.
This method is idempotent and can be called multiple times.
Implementation
Future<void> get started;