Abstract interface for database providers. Provides a unified interface for any database dialect implementation.
Constructors
- DatabaseProvider.forDialect(DatabaseDialect dialect)
-
Creates a new DatabaseProvider for the given
dialect.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAnalyzer(
Database database) → DatabaseAnalyzer -
Creates a new DatabaseAnalyzer for the given
database. -
createConnection(
DatabasePoolManager poolManager) → DatabaseConnection< DatabasePoolManager> -
Creates a new
DatabaseConnectionfor the givenpoolManager. -
createMigrationRunner(
) → MigrationRunner -
Creates a new
MigrationRunner. -
createPoolManager(
SerializationManagerServer serializationManager, RuntimeParametersListBuilder? runtimeParametersBuilder, DatabaseConfig config) → DatabasePoolManager - Creates a new DatabasePoolManager for the given parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited