FileSystemMigrationArtifactStore class
Stores migration artifacts using the current file-system based format.
- Implemented types
Constructors
- FileSystemMigrationArtifactStore({required Directory projectDirectory})
- Creates a new file system migration artifact store.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listVersions(
) → Future< List< String> > -
Lists all available migration versions in ascending order.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readRepairMigration(
) → Future< RepairMigration?> -
Reads the currently available repair migration, if any.
override
-
readVersion(
String version) → Future< MigrationVersionArtifacts?> -
Reads the stored artifacts for a migration version.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeRepairMigration(
RepairMigration repairMigration) → Future< void> -
Persists the provided repair migration, replacing any existing one.
override
-
writeVersion(
MigrationVersionArtifacts artifacts) → Future< void> -
Persists all provided artifacts for a migration version.
override
-
writeVersionRegistry(
List< String> versions) → Future<void> -
Writes the ordered list of migration versions.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited