FutureCallClaimEntry class abstract
Bindings to a future call claim entry in the database.
- Implemented types
Constructors
- FutureCallClaimEntry({int? id, int? futureCallId, required DateTime lastHeartbeatTime})
-
factory
-
FutureCallClaimEntry.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- futureCallId ↔ int?
-
The id of the future call this claim entry is associated with
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pairoverride-getter
- lastHeartbeatTime ↔ DateTime
-
Last heartbeat timestamp for this claim entry.
Used to detect stale claims that should be cleaned up.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ Table<
int?> -
The table that this row belongs to.
no setteroverride
Methods
-
copyWith(
{int? id, int? futureCallId, DateTime? lastHeartbeatTime}) → FutureCallClaimEntry - Returns a shallow copy of this FutureCallClaimEntry with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toJsonForProtocol(
) → Map< String, dynamic> -
Returns a JSON structure of the model, optimized for Protocol communication.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- t → FutureCallClaimEntryTable
-
final
Static Methods
-
include(
) → FutureCallClaimEntryInclude -
includeList(
{WhereExpressionBuilder< FutureCallClaimEntryTable> ? where, int? limit, int? offset, OrderByBuilder<FutureCallClaimEntryTable> ? orderBy, bool orderDescending = false, OrderByListBuilder<FutureCallClaimEntryTable> ? orderByList, FutureCallClaimEntryInclude? include}) → FutureCallClaimEntryIncludeList
Constants
- db → const FutureCallClaimEntryRepository