LogEntryTable class

Inheritance

Constructors

LogEntryTable({TableRelation? tableRelation})

Properties

columns → List<Column>
List of Column used by the table.
no setteroverride
error ↔ ColumnString
Optional error associated with this log entry.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
logLevel ↔ ColumnEnum<LogLevel>
The log level of this entry.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
message ↔ ColumnString
The logging message.
latefinal
messageId ↔ ColumnInt
The message id this entry is associated with, if in a streaming session.
latefinal
order ↔ ColumnInt
The order of this log entry, used for sorting.
latefinal
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
reference ↔ ColumnString
Currently unused.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId ↔ ColumnString
The id of the server which created this log entry.
latefinal
sessionLogId ↔ ColumnInt
The id of the session this log entry is associated with.
latefinal
stackTrace ↔ ColumnString
Optional stack trace associated with this log entry.
latefinal
tableName → String
Name of the table as used in the database.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
time ↔ ColumnDateTime
Timestamp of this log entry.
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited