Persists and loads migration artifacts from a storage implementation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listVersions(
) → Future< List< String> > - Lists all available migration versions in ascending order.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readRepairMigration(
) → Future< RepairMigration?> - Reads the currently available repair migration, if any.
-
readVersion(
String version) → Future< MigrationVersionArtifacts?> - Reads the stored artifacts for a migration version.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeRepairMigration(
RepairMigration repairMigration) → Future< void> - Persists the provided repair migration, replacing any existing one.
-
writeVersion(
MigrationVersionArtifacts artifacts) → Future< void> - Persists all provided artifacts for a migration version.
-
writeVersionRegistry(
List< String> versions) → Future<void> - Writes the ordered list of migration versions.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited