MigrationArtifactStoreWriter class abstract interface

Persists migration artifacts from a storage implementation.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listVersions() Future<List<String>>
Lists all available migration versions in ascending order.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readVersionDefinition(String version) Future<MigrationVersionDefinition?>
Reads the stored definition for a migration version.
toString() String
A string representation of this object.
inherited
writeRepairMigration(RepairMigration repairMigration) Future<void>
Persists the provided repair migration, replacing any existing one.
writeVersion(MigrationVersionArtifacts artifacts) Future<void>
Persists all provided artifacts for a migration version.
writeVersionRegistry(List<String> versions) Future<void>
Writes the ordered list of migration versions.

Operators

operator ==(Object other) bool
The equality operator.
inherited