loadInstalledVersions abstract method
Future<List<DatabaseMigrationVersionModel> >
loadInstalledVersions(
- DatabaseSession session, {
- Transaction? transaction,
Loads the installed versions of the migrations from the database.
This method depends on the table model that will be available only in the server/client package.
Implementation
Future<List<DatabaseMigrationVersionModel>> loadInstalledVersions(
DatabaseSession session, {
Transaction? transaction,
});