RuntimeSettingsRepository class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<RuntimeSettingsTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<RuntimeSettings> rows, {Transaction? transaction})
→ Future<List<RuntimeSettings>>
-
Deletes all RuntimeSettingss in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, RuntimeSettings row, {Transaction? transaction})
→ Future<RuntimeSettings>
-
Deletes a single RuntimeSettings.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<RuntimeSettingsTable> where, Transaction? transaction})
→ Future<List<RuntimeSettings>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<RuntimeSettingsTable>? where, int? limit, int? offset, OrderByBuilder<RuntimeSettingsTable>? orderBy, bool orderDescending = false, OrderByListBuilder<RuntimeSettingsTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<RuntimeSettings>>
-
Returns a list of RuntimeSettingss matching the given query parameters.
-
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<RuntimeSettings?>
-
Finds a single RuntimeSettings by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<RuntimeSettingsTable>? where, int? offset, OrderByBuilder<RuntimeSettingsTable>? orderBy, bool orderDescending = false, OrderByListBuilder<RuntimeSettingsTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<RuntimeSettings?>
-
Returns the first matching RuntimeSettings matching the given query parameters.
-
insert(DatabaseSession session, List<RuntimeSettings> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<RuntimeSettings>>
-
Inserts all RuntimeSettingss in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, RuntimeSettings row, {Transaction? transaction})
→ Future<RuntimeSettings>
-
Inserts a single RuntimeSettings and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<RuntimeSettingsTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on RuntimeSettings rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<RuntimeSettings> rows, {ColumnSelections<RuntimeSettingsTable>? columns, Transaction? transaction})
→ Future<List<RuntimeSettings>>
-
Updates all RuntimeSettingss in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<RuntimeSettingsUpdateTable> columnValues, Transaction? transaction})
→ Future<RuntimeSettings?>
-
Updates a single RuntimeSettings by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, RuntimeSettings row, {ColumnSelections<RuntimeSettingsTable>? columns, Transaction? transaction})
→ Future<RuntimeSettings>
-
Updates a single RuntimeSettings. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<RuntimeSettingsUpdateTable> columnValues, required WhereExpressionBuilder<RuntimeSettingsTable> where, int? limit, int? offset, OrderByBuilder<RuntimeSettingsTable>? orderBy, OrderByListBuilder<RuntimeSettingsTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<RuntimeSettings>>
-
Updates all RuntimeSettingss matching the
where expression with the specified columnValues.
Returns the list of updated rows.