delete method
Future<List<SessionLogEntry> >
delete(
- DatabaseSession session,
- List<
SessionLogEntry> rows, { - OrderByBuilder<
SessionLogEntryTable> ? orderBy, - @Deprecated('Use desc() on the orderBy column instead.') bool orderDescending = false,
- OrderByListBuilder<
SessionLogEntryTable> ? orderByList, - Transaction? transaction,
Deletes all SessionLogEntrys in the list and returns the deleted rows.
To specify the order of the returned rows use orderBy or orderByList
when sorting by multiple columns.
This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
Implementation
Future<List<SessionLogEntry>> delete(
_i1.DatabaseSession session,
List<SessionLogEntry> rows, {
_i1.OrderByBuilder<SessionLogEntryTable>? orderBy,
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false,
_i1.OrderByListBuilder<SessionLogEntryTable>? orderByList,
_i1.Transaction? transaction,
}) async {
return session.db.delete<SessionLogEntry>(
rows,
orderBy: orderBy?.call(SessionLogEntry.t),
orderByList: orderByList?.call(SessionLogEntry.t),
orderDescending: // ignore: deprecated_member_use
orderDescending,
transaction: transaction,
);
}