CloudStorageOptions class final
Options for cloud storage upload operations.
This class is final so that new fields can be added in minor versions
without breaking existing code.
Constructors
- CloudStorageOptions({int? contentLength, bool preventOverwrite = false})
-
Creates a new CloudStorageOptions.
const
Properties
- contentLength → int?
-
When set, the implementation may use this to enforce or optimize
the upload size.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- preventOverwrite → bool
-
When true, the upload should fail if an object already exists at the
given path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited