ConnectionHeaderType class
A class representing the type of connection directives for the Connection header.
Constructors
- ConnectionHeaderType.parse(String value)
-
Parses a
valueand returns the corresponding ConnectionHeaderType instance. If the value does not match any predefined types, it returns a custom instance.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- close → const ConnectionHeaderType
- downgrade → const ConnectionHeaderType
- keepAlive → const ConnectionHeaderType
- upgrade → const ConnectionHeaderType