ExperimentalApi class
Experimental API for Serverpod.
Note: These features are experimental and may change or be removed between minor version releases.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shutdownTasks → TaskManager
-
Shutdown tasks can be used to perform cleanup operations before the server
is shut down. The tasks will be executed asynchronously after the server
has received the shutdown signal.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submitDiagnosticEvent(
DiagnosticEvent event, {required Session session}) → void - Application method for submitting a diagnostic event to registered event handlers. They will execute asynchronously.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited