FutureCallDispatch<T> class
abstract
Provides type-safe access to future calls on the server. Typically, this class is overriden by a FutureCalls class that is generated.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callAtTime(
DateTime time, {String? identifier}) → T - Calls a FutureCall at the specified time, optionally passing a String identifier.
-
callWithDelay(
Duration delay, {String? identifier}) → T -
Calls a FutureCall after the specified
delay, optionally passing a String identifier. -
cancel(
String identifier) → Future< void> - Cancels a FutureCall with the specified identifier. If no future call with the specified identifier is found, this call will have no effect.
-
initialize(
FutureCallManager futureCallManager, String serverId) → void - Initializes the future calls.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited