Geography class abstract
Abstract base class for all PostGIS geography types.
All concrete types (GeographyPoint, GeographyLineString, GeographyPolygon, GeographyGeometryCollection) implement this interface, allowing spatial operations on columns to accept any geography value.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- srid → int
-
Spatial reference system identifier. Defaults to defaultSrid (WGS 84).
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEwkt(
) → String -
Returns the EWKT representation for PostGIS, e.g.
SRID=4326;POINT(-0.12 51.5). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultSrid → const int
- The default spatial reference system identifier: WGS 84 (EPSG:4326).