HealthCheckService class

Service that manages health checks for the server.

This service:

  • Executes health indicators with timeout enforcement
  • Caches results to prevent thundering herd during high-frequency probing
  • Aggregates results into RFC-compliant responses

Constructors

HealthCheckService(Serverpod _pod, HealthConfig _config)
Creates a health check service.

Properties

hashCode int
The hash code for this object.
no setterinherited
readinessIndicators List<HealthIndicator<Object>>
The list of readiness indicators being used.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startupIndicators List<HealthIndicator<Object>>
The list of startup indicators being used.
no setter

Methods

checkLiveness() Future<HealthResponse>
Check liveness (/livez).
checkReadiness() Future<HealthResponse>
Check readiness (/readyz).
checkStartup() Future<HealthResponse>
Check startup (/startupz).
getReadinessResults() Future<List<HealthCheckResult>>
Get all readiness indicator results.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited