IfMatchHeader class final
A class representing the HTTP If-Match header.
- Inheritance
-
- Object
- ETagConditionHeader
- IfMatchHeader
Constructors
- Creates an IfMatchHeader with specific ETags.
-
IfMatchHeader.parse(Iterable<
String> values) -
Parses the If-Match header value.
factory
- IfMatchHeader.wildcard()
-
Creates an IfMatchHeader with wildcard matching.
const
Properties
-
The list of ETags to match against
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isWildcard → bool
-
A boolean value indicating whether the header is a wildcard
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
ETagHeader> -
The list of values that are accepted
finalinherited
Methods
-
encode(
String encodeElement(ETagHeader)) → Iterable< String> -
Converts the header instance into a string representation suitable for HTTP headers
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encodeHeader(
IfMatchHeader header) → List< String>
Constants
-
codec
→ const HeaderCodec<
IfMatchHeader>