JsonWidget class
A WebWidget that renders JSON output. The output will be the result of passing the provided object to jsonEncode.
Constructors
- JsonWidget({required dynamic object})
- Creates a new JsonWidget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- object → dynamic
-
The original object to be rendered as JSON.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{String? onMissingVariable(String)?}) → String -
Renders the widget.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited