NotExpression class
A database expression to invert the result of another expression.
- Inheritance
-
- Object
- Expression<
Expression> - NotExpression
Constructors
- NotExpression(Expression expression)
- Creates a new NotExpression.
Properties
-
columns
→ List<
Column> -
Returns a list of all
Columns in the expression.no setteroverride -
depthFirst
→ Iterable<
Expression> -
Iterator for all
Expressions in the expression. Iterates elements deterministically depth first.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subExpression → Expression
-
Returns the expression wrapped in NOT.
no setter
Methods
-
forEachDepthFirstIndexed(
void action(int index, Expression expression)) → void -
Takes an action for each element.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
wrapExpression(
String expression) → String - Returns the expression as a string wrapped in NOT.
Operators
-
operator &(
Expression other) → Expression -
Database AND operator.
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
Expression other) → Expression -
Database OR operator.
inherited
-
operator ~(
) → Expression -
Database NOT operator.
inherited