PathParameters class
Holds path parameters extracted from a matched route.
This is an AccessorState specialized for path parameters, where keys are Symbols and raw values are Strings.
- Inheritance
-
- Object
- AccessorState<
Symbol, RawPathParam> - PathParameters
Constructors
-
PathParameters(Map<
Symbol, RawPathParam> raw)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ Map<
Symbol, RawPathParam> -
The raw key-value storage.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T extends Object> (ReadOnlyAccessor< T, Symbol, RawPathParam> accessor) → T? -
Returns the decoded value for the given
accessor, ornullif missing.inherited -
get<
T extends Object> (ReadOnlyAccessor< T, Symbol, RawPathParam> accessor) → T -
Returns the decoded value for the given
accessor.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryGet<
T extends Object> (ReadOnlyAccessor< T, Symbol, RawPathParam> accessor) → T? -
Returns the decoded value for the given
accessor, ornullif missing or if decoding fails.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
ReadOnlyAccessor< dynamic, Symbol, RawPathParam> accessor) → RawPathParam? -
Returns the raw value for the given
accessor, ornullif not present.inherited