A savepoint in a transaction.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → Future< void> - Releases the savepoint and any savepoints created after this savepoint.
-
rollback(
) → Future< void> - Rolls back the transaction to the state of the savepoint.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited