getModuleName method
The name of the module that defines the serialization.
This method will be implemented by the generated code.
Implementation
String getModuleName() {
throw UnimplementedError('This protocol does not have a module name.');
}
The name of the module that defines the serialization.
This method will be implemented by the generated code.
String getModuleName() {
throw UnimplementedError('This protocol does not have a module name.');
}