SparseVector class
Represents a sparse vector that stores only non-zero elements.
- Inheritance
-
- Object
- IterableBase<
double> - SparseVector
- Available extensions
Constructors
-
SparseVector(List<
double> value) -
Creates a SparseVector from a list of doubles with all values.
factory
- SparseVector.fromBinary(Uint8List bytes)
-
Creates a SparseVector from its binary representation.
factory
-
SparseVector.fromMap(Map<
int, double> map, int dimensions) -
Creates a SparseVector from a map of indices to values.
factory
Properties
- dimensions → int
-
The total number of dimensions in the vector.
final
- first → double
-
The first element.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
-
indices
→ List<
int> -
The indices of non-zero values in the vector.
final
- isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
double> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → double
-
The last element.
no setterinherited
- length → int
-
The number of elements in this Iterable.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → double
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
-
values
→ List<
double> -
The non-zero values in the vector.
final
Methods
-
any(
bool test(double element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
clone(
) → SparseVector -
Available on SparseVector, provided by the CloneSparseVector extension
Creates a deep copy of the SparseVector, mutations to the original will not affect the copy. -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
elementAt(
int index) → double -
Returns the
indexth element.override -
every(
bool test(double element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(double element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(double element), {double orElse()?}) → double -
The first element that satisfies the given predicate
test.inherited -
fold<
T> (T initialValue, T combine(T previousValue, double element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< double> other) → Iterable<double> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(double element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(double element), {double orElse()?}) → double -
The last element that satisfies the given predicate
test.inherited -
map<
T> (T toElement(double e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
double combine(double value, double element)) → double -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
singleWhere(
bool test(double element), {double orElse()?}) → double -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< double> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(double element)) → Iterable< double> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
take(
int count) → Iterable< double> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(double element)) → Iterable< double> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toBinary(
) → Uint8List - Converts the sparse vector to its binary representation.
-
toJson(
) → String -
Available on SparseVector, provided by the SparseVectorJsonExtension extension
Returns a serialized version of the SparseVector as a String. -
toList(
{bool growable = true}) → List< double> -
Returns the sparse vector as a dense list of double values.
override
-
toSet(
) → Set< double> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
Returns a string representation of (some of) the elements of
this.override -
where(
bool test(double element)) → Iterable< double> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< R> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
-
operator [](
int index) → double -
Returns the value at
index, or0.0if the position is not stored.
Static Methods
-
fromString(
String value) → SparseVector - Creates a SparseVector from a string representation.