TableRowDatabaseJsonExtension extension
Extension on a TableRow to ensure database serialization matches the expected naming of the column in the database
- on
Methods
-
toJsonForDatabase(
) → dynamic -
Available on TableRow, provided by the TableRowDatabaseJsonExtension extension
Returns the json representation to be sent to the database for storage