Holds the state of a running database transaction.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
runtimeParameters
→ Map<
String, dynamic> -
All locally applied runtime parameters.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → Future< void> - Cancels the transaction. Subsequent calls to the database will have no effect and might throw an exception depending on driver.
-
createSavepoint(
) → Future< Savepoint> - Creates a savepoint in the transaction that can be used to rollback to a previous state.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setRuntimeParameters(
RuntimeParametersListBuilder builder) → Future< void> - Sets runtime parameters local to the transaction.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited