WidgetJson class
Deprecated alias for JsonWidget. WidgetJson has been renamed to JsonWidget for consistency.
- Inheritance
-
- Object
- WebWidget
- JsonWidget
- WidgetJson
- Annotations
-
- @Deprecated('Use JsonWidget instead. ' 'WidgetJson has been renamed to JsonWidget for consistency. ' 'This class will be removed in a future version.')
Constructors
- WidgetJson({required dynamic object})
- Creates a new WidgetJson.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- object → dynamic
-
The original object to be rendered as JSON.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited